@@ -1,6 +1,6 @@
 from .empty import EmptyEbook
 from .formatter import BaseFormatter
-from .google_orc import GoogleOCRFormatter
+from .google_ocr import GoogleOCRFormatter
 from .hfml import HFMLFormatter
 from .tsadra import TsadraFormatter
 from .pedurma import PedurmaFormatter
